﻿using System.Collections;
using UnityEngine;
using UnityEngine.InputSystem;

public class PlayerControl : MonoBehaviour
{
    [Header("User settings")]
    public CharacterController control;

    public float speed = 10;

    public float lookPower = 0.1f;

    [Header("Autogenerated values")]
    public Vector3 currentMovement;

    public Vector3 currentLook;

    [Tooltip("Gravitational acceleration.")]
    public Vector3 gravity = new(0, -9.81f, 0);

    [Tooltip("Velocity of gravity.")]
    public Vector3 gravityVelocity;

    public void OnMove(InputAction.CallbackContext context)
    {
        Vector2 rawMove = context.ReadValue<Vector2>();
        currentMovement = new Vector3(rawMove.x, 0, rawMove.y) * speed;
    }

    public void OnLook(InputAction.CallbackContext context)
    {
        Vector2 rawLook = context.ReadValue<Vector2>();
        currentLook = new(0, rawLook.x * lookPower, 0);
    }

    private void FixedUpdate()
    {
        if (control.isGrounded)
        {
            gravityVelocity = Vector3.zero;
        }
        else
        {
            gravityVelocity += gravity * Time.deltaTime;
        }

        control.Move(currentMovement + gravityVelocity);

        transform.Rotate(currentLook);
    }
}